@@ -44,7 +44,7 @@ optional: Dict[str, Any] = {
     "evict_frequency": 5.0,  # how often to run eviction function
     "evict_threshold": 10,  # the number of times a specimen is seen before eviction
     "max_evict": 1,  # how many specimens to evict at a time
-    "evict_func": None,  # function to run during eviction
+    "evict_func": None,  # async function to run during eviction
     "download_dir": "github_download/",  # local directory containing media (images)
     "data_dir": "data/",  # local directory containing the id data
     "group_dir": "group/",  # directory within data_dir containing group lists
@@ -66,6 +66,9 @@ optional: Dict[str, Any] = {
     "category_aliases": {},  # aliases for categories
     "disable_extensions": [],  # bot extensions to disable (media, check, skip, hint, score, sessions, race, other)
     "custom_extensions": [],  # custom bot extensions to enable
+    "hooks": {  # async functions to run at different parts of the lifecycle
+        "before_media_send": None,  # await before_media_send(ctx, item, filename)
+    },
     "sentry": False,  # enable sentry.io error tracking
     "local_redis": True,  # use a local redis server instead of a remote url
     "bot_token_env": "token",  # name of environment variable containing the discord bot token
