@@ -148,6 +148,9 @@ if config.options["sentry"]:
 # ignore format:
 #   ignore:global : [channel id, guild id]
 
+# noholiday format:
+#   noholiday:global : { guild id, ... }
+
 # leave confirm format:
 #   leave:guild_id : 0
 
@@ -392,7 +395,7 @@ def _config():
 
     if config.options["evict_func"] is None:
 
-        def evict(_, category, item):
+        async def evict(_, category, item):
             path = f"{config.options['download_dir']}{category}/{item.lower()}/"
             if os.path.exists(path):
                 shutil.rmtree(path)
