@@ -187,6 +187,12 @@ if config.options["holidays"]:
         Can be extended to other holidays as well.
         """
         logger.info("global check: checking holiday")
+
+        if ctx.command.name == "noholiday":
+            return True
+        if ctx.guild and database.sismember("noholiday:global", str(ctx.guild.id)):
+            return True
+
         now = datetime.now(tz=timezone(-timedelta(hours=4))).date()
         if now == date(now.year, 4, 1):
             return await fools(ctx)
@@ -224,9 +230,7 @@ if config.options["evict_images"]:
     async def refresh_images():
         """Task to delete a random selection of cached images every hour."""
         logger.info("TASK: Refreshing some cache items")
-        event_loop = asyncio.get_event_loop()
-        with concurrent.futures.ThreadPoolExecutor(1) as executor:
-            await event_loop.run_in_executor(executor, evict_images)
+        await evict_images()
 
 
 @tasks.loop(hours=3.0)
